Unit Main;
{ ========================================================================== }
{ =   Lynx Tecnologia Eletrnica Ltda.                                     = }
{ =   Projeto:   Windows Drivers - AC2122               Data: 05/jul/2001  = }
{ =   Programa:  Teste do driver da placa AC2122                           = }
{ =   Mdulo:    Main                                                      = }
{ =   Autor:     Lauro                                                     = }
{ =   Descrio: Window principal do programa.                             = }
{ =   Verso:    1.0                                                       = }
{ ========================================================================== }

{-------------------------  Descrio da Interface  -------------------------}
Interface

Uses Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
     StdCtrls, Buttons, Menus, ExtCtrls,
     TestIRQ, ComCtrls;

{ ===================================================== }
{ =               Declarao de tipos                 = }
{ ===================================================== }

Type
  TMainForm = class(TForm)
    panBack     : TPanel;
    StatusBar   : TStatusBar;
    MainMenu    : TMainMenu;
    panControl  : TPanel;
    btOpen      : TBitBtn;
    btClose     : TBitBtn;
    Arquivo1    : TMenuItem;
    Sair1       : TMenuItem;
    btTestIRQ   : TBitBtn;
    edEnderIP   : TEdit;
    lblEnderIP  : TLabel;
    btConnect   : TBitBtn;
    btDisconnect: TBitBtn;
    btTestIO: TBitBtn;
    Procedure FormCreate (Sender: TObject);
    Procedure FormClose (Sender: TObject; var Action: TCloseAction);
    Procedure btCloseClick (Sender: TObject);
    Procedure btOpenClick (Sender: TObject);
    Procedure btTestIRQClick (Sender: TObject);
    Procedure Sair1Click (Sender: TObject);
    procedure btConnectClick(Sender: TObject);
    procedure btDisconnectClick(Sender: TObject);
    procedure btTestIOClick(Sender: TObject);
  private
    { Private declarations }
    fOpen   : boolean;          // Indica se o driver iniciado
    fConnect: boolean;
    Procedure FinalizaDriver;
    Procedure UpdateCommands;
  public
    { Public declarations }
  end;


{ ===================================================== }
{ =                Variveis globais                  = }
{ ===================================================== }

  Var MainForm: TMainForm;


{-------------------------  Descrio da Implementao ----------------------}
Implementation
  Uses WACapi, TestIO;

{$R *.DFM}

{ ========================================================================== }
{ =                   Implementao do objeto TMainForm                    = }
{ ========================================================================== }

{---------------------------------- TMainForm: Trata criao do formulrio --}
Procedure TMainForm.FormCreate (Sender: TObject);
  Var i   : smallint;
      sAux: string;
begin
  fOpen    := false;
  fConnect := false;
  UpdateCommands;
end;

{------------------------------- TMainForm: Trata fechamento do formulrio --}
Procedure TMainForm.FormClose (Sender: TObject; var Action: TCloseAction);
begin
  FinalizaDriver;
end;

{----------------------- TMainForm: Trata comando para fechar o driver VxD --}
Procedure TMainForm.btCloseClick (Sender: TObject);
begin
  FinalizaDriver;
  StatusBar.Panels.Items [1].Text := '';
  UpdateCommands;
end;

{--------------------- TMainForm: Trata comando para carregar o driver VxD --}
Procedure TMainForm.btOpenClick (Sender: TObject);
  Var VersionHi, VersionLo: byte;
begin
  fOpen := OpenDriver;
  if  fOpen
  then begin
    GetVersion (VersionHi, VersionLo);
    StatusBar.Panels.Items [0].Text := 'WAC2122A' + IntToStr (VersionHi) +
                                       '.' + IntToStr (VersionLo);
  end;
  UpdateCommands;
end;

{-------- TMainForm: Trata comando para estabelecer a conexo com a AC2122 --}
Procedure TMainForm.btConnectClick (Sender: TObject);
  Var szAddrIP: array [0..20] of char;
begin
  if  fOpen
  then begin
    StrPLCopy (@SzAddrIP, edEnderIP.Text, SizeOf (szAddrIP) - 1);
    fConnect := ConnectAC2122 (@SzAddrIP);
    if  not fConnect  then
      MessageDlg ('AC2122 no respondeu.', mtError, [mbOK], 0);
    UpdateCommands;
  end;
end;

{------------- TMainForm: Trata comando para fechar a conexo com a AC2122 --}
Procedure TMainForm.btDisconnectClick (Sender: TObject);
begin
  if  fOpen
  then begin
    DisconnectAC2122;
    fConnect := false;
    UpdateCommands;
  end;
end;

{---------------- TMainForm: Trata comando de teste de aquisio de sinais --}
Procedure TMainForm.btTestIRQClick (Sender: TObject);
begin
  dlgTestIRQ := TdlgTestIRQ.Create (Self);
  dlgTestIRQ.ShowModal;
  dlgTestIRQ.Destroy;
end;

{------------ TMainForm: Trata comando de teste de entrada e saida digital --}
procedure TMainForm.btTestIOClick(Sender: TObject);
begin
  dlgTestIO := TdlgTestIO.Create (Self);
  dlgTestIO.ShowModal;
  dlgTestIO.Destroy;
end;

{-------------------------------------------- TMainForm: Finaliza o driver --}
Procedure TMainForm.FinalizaDriver;
begin
  if  fOpen
  then begin
    DisconnectAC2122;
    CloseDriver;        // Fecha o acesso ao driver
    fOpen := false;
  end;
end;

{----------------------------------------- TMainForm: Finaliza a aplicao --}
Procedure TMainForm.Sair1Click (Sender: TObject);
begin
  Close;
end;

{------------------------------ TMainForm: Atualiza habilitao dos botes --}
Procedure TMainForm.UpdateCommands;
begin
  btOpen.Enabled       := not fOpen;
  btClose.Enabled      := fOpen;
  btConnect.Enabled    := fOpen and (not fConnect);
  btDisconnect.Enabled := fOpen and fConnect;
  btTestIRQ.Enabled    := fOpen and fConnect;
  btTestIO.Enabled     := fOpen and fConnect;
end;

end.
